@@ -11,6 +11,11 @@ impl SecretValidator for GithubSecretValidator {
     fn validate(&self, headers: &HeaderMap, body: &[u8], secret: &[u8]) -> bool {
         log::debug!("Validating GitHub Secret");
         if let Some(github_sum) = headers.get(X_HUB_SIGNATURE_256_HEADER) {
+            let mut github_sum = github_sum.to_str().unwrap();
+            github_sum = github_sum
+                .split_once("=")
+                .map(|(_, s)| s)
+                .unwrap_or(github_sum);
             let mut mac = Hmac::<Sha256>::new_from_slice(secret).unwrap();
             mac.update(body);
 
