@@ -1,6 +1,8 @@
+use crate::secret_validation::SecretValidator;
 use crate::server::command_template::CommandTemplate;
-use crate::utils::error::MultihookResult;
-use crate::utils::settings::EndpointSettings;
+use crate::utils::error::{MultihookError, MultihookResult};
+use crate::utils::settings::{EndpointSettings, SecretSettings};
+use hyper::http::request::Parts;
 use hyper::{Body, Request};
 use serde_json::Value;
 use std::fs::read_to_string;
@@ -17,10 +19,16 @@ pub struct HookAction {
     command: CommandTemplate,
     parallel_lock: Arc<Semaphore>,
     run_detached: bool,
+    secret: Option<SecretSettings>,
 }
 
 impl HookAction {
-    pub fn new<S: ToString>(command: S, parallel: bool, detached: bool) -> Self {
+    pub fn new<S: ToString>(
+        command: S,
+        parallel: bool,
+        detached: bool,
+        secret: Option<SecretSettings>,
+    ) -> Self {
         let parallel_lock = if parallel {
             Semaphore::new(MAX_CONCURRENCY)
         } else {
@@ -30,12 +38,17 @@ impl HookAction {
             command: CommandTemplate::new(command),
             parallel_lock: Arc::new(parallel_lock),
             run_detached: detached,
+            secret,
         }
     }
 
     pub async fn execute(&self, req: Request<Body>) -> MultihookResult<()> {
-        let body = hyper::body::to_bytes(req.into_body()).await?.to_vec();
+        let (parts, body) = req.into_parts();
+        let body = hyper::body::to_bytes(body).await?.to_vec();
+
+        self.validate_secret(&parts, &body)?;
         let body = String::from_utf8(body)?;
+
         if self.run_detached {
             tokio::spawn({
                 let action = self.clone();
@@ -52,6 +65,16 @@ impl HookAction {
         }
     }
 
+    fn validate_secret(&self, parts: &Parts, body: &Vec<u8>) -> MultihookResult<()> {
+        if let Some(secret) = &self.secret {
+            let validator = secret.format.validator();
+            if !validator.validate(&parts.headers, &body, &secret.value.as_bytes()) {
+                return Err(MultihookError::InvalidSecret);
+            }
+        }
+        Ok(())
+    }
+
     async fn execute_command(&self, body: &str) -> MultihookResult<()> {
         let json_body: Value = serde_json::from_str(body).unwrap_or_default();
         let command = self.command.evaluate(&json_body);
@@ -85,6 +108,11 @@ impl From<&EndpointSettings> for HookAction {
         let action = endpoint.action.clone();
         let path = PathBuf::from(&action);
         let contents = read_to_string(path).unwrap_or(action);
-        Self::new(contents, endpoint.allow_parallel, endpoint.run_detached)
+        Self::new(
+            contents,
+            endpoint.allow_parallel,
+            endpoint.run_detached,
+            endpoint.secret.clone(),
+        )
     }
 }
